@@ -35,7 +35,7 @@ mod resource_manager;
 mod property;
 pub mod math;
 pub use resource_manager::{ResourceManager, ImageLoader, Provider, FileProvider};
-pub use property::PropertyContainer;
+pub use property::{PropertyContainer, Property};
 pub use errors::Error;
 pub use errors::Result;
 
@@ -943,12 +943,12 @@ mod test {
         use Layer::*;
         macro_rules! layer {
             (tile) => {Tile(TileLayer{
-                id: 0, name: "".into(), size: math::ivec2::new(0,0),
+                id: Some(0), name: "".into(), size: math::ivec2::new(0,0),
                 tintcolor: Color::default(), tiles: vec![],
                 properties: PropertyContainer::new(),
             })};
             (group $layers:expr) => {Group(GroupLayer{
-                id:0, name: "".into(), offset: math::ivec2::new(0,0),
+                id: Some(0), name: "".into(), offset: math::ivec2::new(0,0),
                 opacity: 0., tintcolor: Color::default(), visible:false,
                 content: $layers, properties: PropertyContainer::new(),
             })};
